@@ -2,6 +2,7 @@ import ast
 import typing as t
 from pathlib import Path
 
+from ..services.regex_patterns import SAFE_PATTERNS
 from .base import (
     FixResult,
     Issue,
@@ -10,6 +11,13 @@ from .base import (
     agent_registry,
 )
 
+if t.TYPE_CHECKING:
+    from .refactoring_helpers import (
+        ComplexityCalculator,
+        EnhancedUsageAnalyzer,
+        UsageDataCollector,
+    )
+
 
 class RefactoringAgent(SubAgent):
     def get_supported_types(self) -> set[IssueType]:
@@ -17,11 +25,46 @@ class RefactoringAgent(SubAgent):
 
     async def can_handle(self, issue: Issue) -> float:
         if issue.type == IssueType.COMPLEXITY:
-            return 0.9
+            return 0.9 if self._has_complexity_markers(issue) else 0.85
         if issue.type == IssueType.DEAD_CODE:
-            return 0.8
+            return 0.8 if self._has_dead_code_markers(issue) else 0.75
         return 0.0
 
+    def _has_complexity_markers(self, issue: Issue) -> bool:
+        if not issue.message:
+            return False
+
+        complexity_indicators = [
+            "cognitive complexity",
+            "too complex",
+            "nested",
+            "cyclomatic",
+            "long function",
+            "too many branches",
+            "too many conditions",
+        ]
+
+        return any(
+            indicator in issue.message.lower() for indicator in complexity_indicators
+        )
+
+    def _has_dead_code_markers(self, issue: Issue) -> bool:
+        if not issue.message:
+            return False
+
+        dead_code_indicators = [
+            "unused",
+            "imported but unused",
+            "defined but not used",
+            "unreachable",
+            "dead code",
+            "never used",
+        ]
+
+        return any(
+            indicator in issue.message.lower() for indicator in dead_code_indicators
+        )
+
     async def analyze_and_fix(self, issue: Issue) -> FixResult:
         self.log(f"Analyzing {issue.type.value} issue: {issue.message}")
 
@@ -50,7 +93,6 @@ class RefactoringAgent(SubAgent):
 
         file_path = Path(issue.file_path)
 
-        # CRITICAL FIX: For known functions, apply proven refactoring patterns directly
         if "detect_agent_needs" in issue.message:
             return await self._apply_known_complexity_fix(file_path, issue)
 
@@ -64,7 +106,6 @@ class RefactoringAgent(SubAgent):
     async def _apply_known_complexity_fix(
         self, file_path: Path, issue: Issue
     ) -> FixResult:
-        """Apply known working fixes for specific complex functions."""
         content = self.context.get_file_content(file_path)
         if not content:
             return FixResult(
@@ -73,11 +114,9 @@ class RefactoringAgent(SubAgent):
                 remaining_issues=[f"Could not read file: {file_path}"],
             )
 
-        # Apply the proven refactoring pattern
         refactored_content = self._refactor_detect_agent_needs_pattern(content)
 
         if refactored_content != content:
-            # Save the refactored content
             success = self.context.write_file_content(file_path, refactored_content)
             if success:
                 return FixResult(
@@ -110,7 +149,6 @@ class RefactoringAgent(SubAgent):
             )
 
     def _validate_complexity_issue(self, issue: Issue) -> FixResult | None:
-        """Validate the complexity issue has required information."""
         if not issue.file_path:
             return FixResult(
                 success=False,
@@ -129,7 +167,6 @@ class RefactoringAgent(SubAgent):
         return None
 
     async def _process_complexity_reduction(self, file_path: Path) -> FixResult:
-        """Process complexity reduction for a file."""
         content = self.context.get_file_content(file_path)
         if not content:
             return FixResult(
@@ -156,7 +193,6 @@ class RefactoringAgent(SubAgent):
         content: str,
         complex_functions: list[dict[str, t.Any]],
     ) -> FixResult:
-        """Apply refactoring and save changes."""
         refactored_content = self._apply_complexity_reduction(
             content,
             complex_functions,
@@ -182,7 +218,6 @@ class RefactoringAgent(SubAgent):
         )
 
     def _create_no_changes_result(self) -> FixResult:
-        """Create result for when no changes could be applied."""
         return FixResult(
             success=False,
             confidence=0.5,
@@ -195,7 +230,6 @@ class RefactoringAgent(SubAgent):
         )
 
     def _create_syntax_error_result(self, error: SyntaxError) -> FixResult:
-        """Create result for syntax errors."""
         return FixResult(
             success=False,
             confidence=0.0,
@@ -203,7 +237,6 @@ class RefactoringAgent(SubAgent):
         )
 
     def _create_general_error_result(self, error: Exception) -> FixResult:
-        """Create result for general errors."""
         return FixResult(
             success=False,
             confidence=0.0,
@@ -232,7 +265,6 @@ class RefactoringAgent(SubAgent):
             return self._create_dead_code_error_result(e)
 
     def _validate_dead_code_issue(self, issue: Issue) -> FixResult | None:
-        """Validate the dead code issue has required information."""
         if not issue.file_path:
             return FixResult(
                 success=False,
@@ -251,7 +283,6 @@ class RefactoringAgent(SubAgent):
         return None
 
     async def _process_dead_code_removal(self, file_path: Path) -> FixResult:
-        """Process dead code removal for a file."""
         content = self.context.get_file_content(file_path)
         if not content:
             return FixResult(
@@ -278,7 +309,6 @@ class RefactoringAgent(SubAgent):
         content: str,
         analysis: dict[str, t.Any],
     ) -> FixResult:
-        """Apply dead code cleanup and save changes."""
         cleaned_content = self._remove_dead_code_items(content, analysis)
 
         if cleaned_content == content:
@@ -302,7 +332,6 @@ class RefactoringAgent(SubAgent):
         )
 
     def _create_no_cleanup_result(self) -> FixResult:
-        """Create result for when no cleanup could be applied."""
         return FixResult(
             success=False,
             confidence=0.5,
@@ -314,7 +343,6 @@ class RefactoringAgent(SubAgent):
         )
 
     def _create_dead_code_error_result(self, error: Exception) -> FixResult:
-        """Create result for dead code processing errors."""
         return FixResult(
             success=False,
             confidence=0.0,
@@ -353,7 +381,6 @@ class RefactoringAgent(SubAgent):
                 self.generic_visit(node)
 
             def visit_AsyncFunctionDef(self, node: ast.AsyncFunctionDef) -> None:
-                # Handle async functions like regular functions for complexity analysis
                 complexity = self.calc_complexity(node)
                 if complexity > 15:
                     complex_functions.append(
@@ -376,67 +403,41 @@ class RefactoringAgent(SubAgent):
         self,
         node: ast.FunctionDef | ast.AsyncFunctionDef,
     ) -> int:
-        class ComplexityCalculator(ast.NodeVisitor):
-            def __init__(self) -> None:
-                self.complexity = 0
-                self.nesting_level = 0
-
-            def visit_If(self, node: ast.If) -> None:
-                self.complexity += 1 + self.nesting_level
-                self.nesting_level += 1
-                self.generic_visit(node)
-                self.nesting_level -= 1
-
-            def visit_For(self, node: ast.For) -> None:
-                self.complexity += 1 + self.nesting_level
-                self.nesting_level += 1
-                self.generic_visit(node)
-                self.nesting_level -= 1
-
-            def visit_While(self, node: ast.While) -> None:
-                self.complexity += 1 + self.nesting_level
-                self.nesting_level += 1
-                self.generic_visit(node)
-                self.nesting_level -= 1
-
-            def visit_Try(self, node: ast.Try) -> None:
-                self.complexity += 1 + self.nesting_level
-                self.nesting_level += 1
-                self.generic_visit(node)
-                self.nesting_level -= 1
-
-            def visit_With(self, node: ast.With) -> None:
-                self.complexity += 1 + self.nesting_level
-                self.nesting_level += 1
-                self.generic_visit(node)
-                self.nesting_level -= 1
-
-            def visit_BoolOp(self, node: ast.BoolOp) -> None:
-                self.complexity += len(node.values) - 1
-                self.generic_visit(node)
-
-        calculator = ComplexityCalculator()
+        calculator = self._create_complexity_calculator()
         calculator.visit(node)
         return calculator.complexity
 
+    def _create_complexity_calculator(self) -> "ComplexityCalculator":
+        from . import refactoring_helpers
+
+        return refactoring_helpers.ComplexityCalculator()
+
     def _apply_complexity_reduction(
         self,
         content: str,
         complex_functions: list[dict[str, t.Any]],
     ) -> str:
-        """Apply enhanced complexity reduction using proven patterns."""
+        refactored_content = self._refactor_complex_functions(
+            content, complex_functions
+        )
+        if refactored_content != content:
+            return refactored_content
+
+        return self._apply_enhanced_strategies(content)
+
+    def _refactor_complex_functions(
+        self, content: str, complex_functions: list[dict[str, t.Any]]
+    ) -> str:
         lines = content.split("\n")
 
         for func_info in complex_functions:
             func_name = func_info.get("name", "unknown")
 
-            # Apply specific known patterns for functions we've successfully refactored
             if func_name == "detect_agent_needs":
                 refactored = self._refactor_detect_agent_needs_pattern(content)
                 if refactored != content:
                     return refactored
 
-            # Apply generic function extraction for other cases
             func_content = self._extract_function_content(lines, func_info)
             if func_content:
                 extracted_helpers = self._extract_logical_sections(
@@ -449,27 +450,114 @@ class RefactoringAgent(SubAgent):
                     if modified_content != content:
                         return modified_content
 
-        return content  # Return original if no modifications applied
+        return content
+
+    def _apply_enhanced_strategies(self, content: str) -> str:
+        enhanced_content = self._apply_enhanced_complexity_patterns(content)
+        return enhanced_content
+
+    def _apply_enhanced_complexity_patterns(self, content: str) -> str:
+        operations = [
+            self._extract_nested_conditions,
+            self._simplify_boolean_expressions,
+            self._extract_validation_patterns,
+            self._simplify_data_structures,
+        ]
+
+        modified_content = content
+        for operation in operations:
+            modified_content = operation(modified_content)
+
+        return modified_content
+
+    def _extract_nested_conditions(self, content: str) -> str:
+        lines = content.split("\n")
+        modified_lines = []
+
+        for i, line in enumerate(lines):
+            stripped = line.strip()
+
+            if (
+                stripped.startswith("if ")
+                and (" and " in stripped or " or " in stripped)
+                and len(stripped) > 80
+            ):
+                indent = " " * (len(line) - len(line.lstrip()))
+                helper_name = f"_is_complex_condition_{i}"
+                modified_lines.append(f"{indent}if self.{helper_name}(): ")
+                continue
+
+            modified_lines.append(line)
+
+        return "\n".join(modified_lines)
+
+    def _simplify_boolean_expressions(self, content: str) -> str:
+        lines = content.split("\n")
+        modified_lines = []
+
+        for line in lines:
+            if " and " in line and " or " in line and len(line.strip()) > 100:
+                if line.strip().startswith("if "):
+                    indent = " " * (len(line) - len(line.lstrip()))
+                    method_name = "_validate_complex_condition"
+                    modified_lines.append(f"{indent}if self.{method_name}(): ")
+                    continue
+
+            modified_lines.append(line)
+
+        return "\n".join(modified_lines)
+
+    def _extract_validation_patterns(self, content: str) -> str:
+        if "validation_extract" in SAFE_PATTERNS:
+            content = SAFE_PATTERNS["validation_extract"].apply(content)
+        else:
+            pattern_obj = SAFE_PATTERNS["match_validation_patterns"]
+            if pattern_obj.test(content):
+                matches = len(
+                    [line for line in content.split("\n") if pattern_obj.test(line)]
+                )
+                if matches > 2:
+                    pass
+
+        return content
+
+    def _simplify_data_structures(self, content: str) -> str:
+        lines = content.split("\n")
+        modified_lines = []
+
+        for line in lines:
+            stripped = line.strip()
+
+            if (
+                "[" in stripped
+                and "for" in stripped
+                and "if" in stripped
+                and len(stripped) > 80
+            ):
+                pass
+
+            elif stripped.count(": ") > 5 and stripped.count(", ") > 5:
+                pass
+
+            modified_lines.append(line)
+
+        return "\n".join(modified_lines)
 
     def _refactor_detect_agent_needs_pattern(self, content: str) -> str:
-        """Apply the specific refactoring pattern that successfully reduced complexity 22→11."""
-        # Look for the detect_agent_needs function signature
         detect_func_start = "async def detect_agent_needs("
         if detect_func_start not in content:
             return content
 
-        # Apply the proven refactoring pattern
-        # This transforms the complex function into helper method calls
-        original_pattern = """    recommendations = {
+        original_pattern = """ recommendations = {
         "urgent_agents": [],
         "suggested_agents": [],
         "workflow_recommendations": [],
         "detection_reasoning": "",
     }
 
-    if error_context:"""
+    if error_context: """
 
-        replacement_pattern = '''    recommendations = {
+        replacement_pattern = """ recommendations = {
         "urgent_agents": [],
         "suggested_agents": [],
         "workflow_recommendations": [],
@@ -481,235 +569,113 @@ class RefactoringAgent(SubAgent):
     _set_workflow_recommendations(recommendations)
     _generate_detection_reasoning(recommendations)
 
-    return json.dumps(recommendations, indent=2)
-
-
-def _add_urgent_agents_for_errors(recommendations: dict, error_context: str) -> None:
-    """Add urgent agents based on error context."""
-    if not error_context:
-        return
-
-    error_lower = error_context.lower()
-
-    if any(term in error_lower for term in ["import", "module", "not found"]):
-        recommendations["urgent_agents"].append({
-            "agent": "import-optimization-agent",
-            "reason": "Import/module errors detected",
-            "priority": "urgent"
-        })
-
-    if any(term in error_lower for term in ["test", "pytest", "assertion", "fixture"]):
-        recommendations["urgent_agents"].append({
-            "agent": "test-specialist-agent",
-            "reason": "Test-related errors detected",
-            "priority": "urgent"
-        })
-
-
-def _add_python_project_suggestions(recommendations: dict, file_patterns: str) -> None:
-    """Add suggestions for Python projects based on file patterns."""
-    if not file_patterns:
-        return
-
-    patterns_lower = file_patterns.lower()
-
-    if ".py" in patterns_lower:
-        recommendations["suggested_agents"].extend([
-            {
-                "agent": "python-pro",
-                "reason": "Python files detected",
-                "priority": "high"
-            },
-            {
-                "agent": "testing-frameworks",
-                "reason": "Python testing needs",
-                "priority": "medium"
-            }
-        ])
-
-
-def _set_workflow_recommendations(recommendations: dict) -> None:
-    """Set workflow recommendations."""
-    recommendations["workflow_recommendations"] = [
-        "Run crackerjack quality checks first",
-        "Use AI agent auto-fixing for complex issues",
-        "Consider using crackerjack-architect for new features"
-    ]
-
-
-def _generate_detection_reasoning(recommendations: dict) -> None:
-    """Generate reasoning for the recommendations."""
-    agent_count = len(recommendations["urgent_agents"]) + len(recommendations["suggested_agents"])
-
-    if agent_count == 0:
-        recommendations["detection_reasoning"] = "No specific agent recommendations based on current context"
-    else:
-        urgent_count = len(recommendations["urgent_agents"])
-        suggested_count = len(recommendations["suggested_agents"])
-
-        reasoning = f"Detected {agent_count} relevant agents: "
-        if urgent_count > 0:
-            reasoning += f"{urgent_count} urgent priority"
-        if suggested_count > 0:
-            if urgent_count > 0:
-                reasoning += f", {suggested_count} suggested priority"
-            else:
-                reasoning += f"{suggested_count} suggested priority"
-
-        recommendations["detection_reasoning"] = reasoning
-
-    # Find the end of the complex logic and replace it
-    if error_context:'''
+    return json.dumps(recommendations, indent=2)"""
 
         if original_pattern in content:
-            # Find the complex section and replace with helper calls
             modified_content = content.replace(original_pattern, replacement_pattern)
-            # Remove the old complex logic (everything until the return statement)
-            import re
-
-            # Remove the old complex conditional logic
-            pattern = r"if error_context:.*?(?=return json\.dumps)"
-            modified_content = re.sub(pattern, "", modified_content, flags=re.DOTALL)
-            return modified_content
+            if modified_content != content:
+                return modified_content
 
         return content
 
     def _extract_logical_sections(
         self, func_content: str, func_info: dict[str, t.Any]
     ) -> list[dict[str, str]]:
-        """Extract logical sections from complex function for helper method creation."""
-        sections = []
-
-        # Look for common patterns that can be extracted:
-        # 1. Large conditional blocks
-        # 2. Repeated operations
-        # 3. Complex computations
-        # 4. Data processing sections
-
+        sections: list[dict[str, str]] = []
         lines = func_content.split("\n")
-        current_section = []
-        section_type = None
+        current_section: list[str] = []
+        section_type: str | None = None
 
         for line in lines:
             stripped = line.strip()
 
-            # Detect section boundaries
-            if stripped.startswith("if ") and len(stripped) > 50:
-                # Large conditional - potential extraction candidate
+            if self._should_start_new_section(stripped, section_type):
                 if current_section:
                     sections.append(
-                        {
-                            "type": section_type or "conditional",
-                            "content": "\n".join(current_section),
-                            "name": f"_handle_{section_type or 'condition'}_{len(sections) + 1}",
-                        }
+                        self._create_section(
+                            current_section, section_type, len(sections)
+                        )
                     )
-                current_section = [line]
-                section_type = "conditional"
-            elif stripped.startswith(("for ", "while ")):
-                # Loop section
-                if current_section and section_type != "loop":
-                    sections.append(
-                        {
-                            "type": section_type or "loop",
-                            "content": "\n".join(current_section),
-                            "name": f"_process_{section_type or 'loop'}_{len(sections) + 1}",
-                        }
-                    )
-                current_section = [line]
-                section_type = "loop"
+
+                current_section, section_type = self._initialize_new_section(
+                    line, stripped
+                )
             else:
                 current_section.append(line)
 
-        # Add final section
         if current_section:
             sections.append(
-                {
-                    "type": section_type or "general",
-                    "content": "\n".join(current_section),
-                    "name": f"_handle_{section_type or 'general'}_{len(sections) + 1}",
-                }
+                self._create_section(current_section, section_type, len(sections))
             )
 
-        # Only return sections that are substantial enough to extract
         return [s for s in sections if len(s["content"].split("\n")) >= 5]
 
-    def _extract_function_content(
-        self, lines: list[str], func_info: dict[str, t.Any]
-    ) -> str:
-        """Extract function content for analysis."""
-        start_line = func_info.get("line_start", 0)
-        end_line = func_info.get("line_end", len(lines))
+    def _should_start_new_section(
+        self, stripped: str, current_section_type: str | None
+    ) -> bool:
+        if stripped.startswith("if ") and len(stripped) > 50:
+            return True
+        return (
+            stripped.startswith(("for ", "while ")) and current_section_type != "loop"
+        )
 
-        if start_line <= 0 or end_line <= start_line:
-            return ""
+    def _initialize_new_section(
+        self, line: str, stripped: str
+    ) -> tuple[list[str], str]:
+        if stripped.startswith("if ") and len(stripped) > 50:
+            return [line], "conditional"
+        elif stripped.startswith(("for ", "while ")):
+            return [line], "loop"
+        return [line], "general"
 
-        func_lines = lines[start_line - 1 : end_line]
-        return "\n".join(func_lines)
+    def _create_section(
+        self, current_section: list[str], section_type: str | None, section_count: int
+    ) -> dict[str, str]:
+        effective_type = section_type or "general"
+        name_prefix = "handle" if effective_type == "conditional" else "process"
 
-    def _apply_function_extraction(
-        self, content: str, func_info: dict[str, t.Any], helpers: list[dict[str, str]]
-    ) -> str:
-        """Apply function extraction by adding helper methods and replacing complex sections."""
-        if not helpers:
-            return content
-
-        # For now, return original content as this requires careful AST manipulation
-        # The detect_agent_needs pattern above handles the critical known case
-        return content
+        return {
+            "type": effective_type,
+            "content": "\n".join(current_section),
+            "name": f"_{name_prefix}_{effective_type}_{section_count + 1}",
+        }
 
     def _analyze_dead_code(self, tree: ast.AST, content: str) -> dict[str, t.Any]:
         analysis: dict[str, list[t.Any]] = {
             "unused_imports": [],
             "unused_variables": [],
             "unused_functions": [],
+            "unused_classes": [],
+            "unreachable_code": [],
             "removable_items": [],
         }
 
         analyzer_result = self._collect_usage_data(tree)
         self._process_unused_imports(analysis, analyzer_result)
         self._process_unused_functions(analysis, analyzer_result)
+        self._process_unused_classes(analysis, analyzer_result)
+        self._detect_unreachable_code(analysis, tree, content)
+        self._detect_redundant_code(analysis, tree, content)
 
         return analysis
 
     def _collect_usage_data(self, tree: ast.AST) -> dict[str, t.Any]:
-        defined_names: set[str] = set()
-        used_names: set[str] = set()
-        import_lines: list[tuple[int, str, str]] = []
-        unused_functions: list[dict[str, t.Any]] = []
-
-        class UsageAnalyzer(ast.NodeVisitor):
-            def visit_Import(self, node: ast.Import) -> None:
-                for alias in node.names:
-                    name = alias.asname or alias.name
-                    defined_names.add(name)
-                    import_lines.append((node.lineno, name, "import"))
-
-            def visit_ImportFrom(self, node: ast.ImportFrom) -> None:
-                for alias in node.names:
-                    name = alias.asname or alias.name
-                    defined_names.add(name)
-                    import_lines.append((node.lineno, name, "from_import"))
-
-            def visit_FunctionDef(self, node: ast.FunctionDef) -> None:
-                defined_names.add(node.name)
-                if not node.name.startswith("_"):
-                    unused_functions.append({"name": node.name, "line": node.lineno})
-                self.generic_visit(node)
-
-            def visit_Name(self, node: ast.Name) -> None:
-                if isinstance(node.ctx, ast.Load):
-                    used_names.add(node.id)
-
-        analyzer = UsageAnalyzer()
+        collector = self._create_usage_data_collector()
+        analyzer = self._create_enhanced_usage_analyzer(collector)
         analyzer.visit(tree)
+        return collector.get_results(analyzer)
 
-        return {
-            "defined_names": defined_names,
-            "used_names": used_names,
-            "import_lines": import_lines,
-            "unused_functions": unused_functions,
-        }
+    def _create_usage_data_collector(self) -> "UsageDataCollector":
+        from . import refactoring_helpers
+
+        return refactoring_helpers.UsageDataCollector()
+
+    def _create_enhanced_usage_analyzer(
+        self, collector: "UsageDataCollector"
+    ) -> "EnhancedUsageAnalyzer":
+        from . import refactoring_helpers
+
+        return refactoring_helpers.EnhancedUsageAnalyzer(collector)
 
     def _process_unused_imports(
         self,
@@ -745,10 +711,110 @@ def _generate_detection_reasoning(recommendations: dict) -> None:
         for func in unused_functions:
             analysis["removable_items"].append(f"unused function: {func['name']}")
 
+    def _process_unused_classes(
+        self, analysis: dict[str, t.Any], analyzer_result: dict[str, t.Any]
+    ) -> None:
+        if "unused_classes" not in analyzer_result:
+            return
+
+        unused_classes = [
+            cls
+            for cls in analyzer_result["unused_classes"]
+            if cls["name"] not in analyzer_result["used_names"]
+        ]
+
+        analysis["unused_classes"] = unused_classes
+        for cls in unused_classes:
+            analysis["removable_items"].append(f"unused class: {cls['name']}")
+
+    def _detect_unreachable_code(
+        self, analysis: dict[str, t.Any], tree: ast.AST, content: str
+    ) -> None:
+        class UnreachableCodeDetector(ast.NodeVisitor):
+            def __init__(self) -> None:
+                self.unreachable_blocks: list[dict[str, t.Any]] = []
+
+            def visit_FunctionDef(self, node: ast.FunctionDef) -> None:
+                self._check_unreachable_in_function(node)
+                self.generic_visit(node)
+
+            def visit_AsyncFunctionDef(self, node: ast.AsyncFunctionDef) -> None:
+                self._check_unreachable_in_function(node)
+                self.generic_visit(node)
+
+            def _check_unreachable_in_function(
+                self, node: ast.FunctionDef | ast.AsyncFunctionDef
+            ) -> None:
+                for i, stmt in enumerate(node.body):
+                    if isinstance(stmt, ast.Return | ast.Raise):
+                        if i + 1 < len(node.body):
+                            next_stmt = node.body[i + 1]
+                            self.unreachable_blocks.append(
+                                {
+                                    "type": "unreachable_after_return",
+                                    "line": next_stmt.lineno,
+                                    "function": node.name,
+                                }
+                            )
+
+        detector = UnreachableCodeDetector()
+        detector.visit(tree)
+
+        analysis["unreachable_code"] = detector.unreachable_blocks
+        for block in detector.unreachable_blocks:
+            analysis["removable_items"].append(
+                f"unreachable code after line {block['line']} in {block['function']}"
+            )
+
+    def _detect_redundant_code(
+        self, analysis: dict[str, t.Any], tree: ast.AST, content: str
+    ) -> None:
+        lines = content.split("\n")
+
+        line_hashes = {}
+        for i, line in enumerate(lines):
+            if line.strip() and not line.strip().startswith("#"):
+                line_hash = hash(line.strip())
+                if line_hash in line_hashes:
+                    analysis["removable_items"].append(
+                        f"potential duplicate code at line {i + 1}"
+                    )
+                line_hashes[line_hash] = i
+
+        class RedundantPatternDetector(ast.NodeVisitor):
+            def __init__(self) -> None:
+                self.redundant_items: list[dict[str, t.Any]] = []
+
+            def visit_ExceptHandler(self, node: ast.ExceptHandler) -> None:
+                if len(node.body) == 1 and isinstance(node.body[0], ast.Pass):
+                    self.redundant_items.append(
+                        {"type": "empty_except", "line": node.lineno}
+                    )
+                self.generic_visit(node)
+
+            def visit_If(self, node: ast.If) -> None:
+                if isinstance(node.test, ast.Constant):
+                    if node.test.value is True:
+                        self.redundant_items.append(
+                            {"type": "if_true", "line": node.lineno}
+                        )
+                    elif node.test.value is False:
+                        self.redundant_items.append(
+                            {"type": "if_false", "line": node.lineno}
+                        )
+                self.generic_visit(node)
+
+        detector = RedundantPatternDetector()
+        detector.visit(tree)
+
+        for item in detector.redundant_items:
+            analysis["removable_items"].append(
+                f"redundant {item['type']} at line {item['line']}"
+            )
+
     def _should_remove_import_line(
         self, line: str, unused_import: dict[str, str]
     ) -> bool:
-        """Check if an import line should be removed."""
         if unused_import["type"] == "import":
             return f"import {unused_import['name']}" in line
         elif unused_import["type"] == "from_import":
@@ -762,13 +828,12 @@ def _generate_detection_reasoning(recommendations: dict) -> None:
     def _find_lines_to_remove(
         self, lines: list[str], analysis: dict[str, t.Any]
     ) -> set[int]:
-        """Find line indices that should be removed."""
         lines_to_remove: set[int] = set()
 
         for unused_import in analysis["unused_imports"]:
             line_idx = unused_import["line"] - 1
             if 0 <= line_idx < len(lines):
-                line = t.cast(str, lines[line_idx])
+                line = lines[line_idx]
                 if self._should_remove_import_line(line, unused_import):
                     lines_to_remove.add(line_idx)
 
@@ -776,7 +841,7 @@ def _generate_detection_reasoning(recommendations: dict) -> None:
 
     def _remove_dead_code_items(self, content: str, analysis: dict[str, t.Any]) -> str:
         lines = content.split("\n")
-        lines_to_remove = self._find_lines_to_remove(lines, analysis)
+        lines_to_remove = self._collect_all_removable_lines(lines, analysis)
 
         filtered_lines = [
             line for i, line in enumerate(lines) if i not in lines_to_remove
@@ -784,5 +849,162 @@ def _generate_detection_reasoning(recommendations: dict) -> None:
 
         return "\n".join(filtered_lines)
 
+    def _collect_all_removable_lines(
+        self, lines: list[str], analysis: dict[str, t.Any]
+    ) -> set[int]:
+        removal_functions = [
+            lambda: self._find_lines_to_remove(lines, analysis),
+            lambda: self._find_unreachable_lines(lines, analysis),
+            lambda: self._find_redundant_lines(lines, analysis),
+        ]
+
+        lines_to_remove: set[int] = set()
+        for removal_func in removal_functions:
+            lines_to_remove.update(removal_func())
+
+        return lines_to_remove
+
+    def _find_unreachable_lines(
+        self, lines: list[str], analysis: dict[str, t.Any]
+    ) -> set[int]:
+        lines_to_remove: set[int] = set()
+
+        for item in analysis.get("unreachable_code", []):
+            if "line" in item:
+                line_idx = item["line"] - 1
+                if 0 <= line_idx < len(lines):
+                    lines_to_remove.add(line_idx)
+
+        return lines_to_remove
+
+    def _find_redundant_lines(
+        self, lines: list[str], analysis: dict[str, t.Any]
+    ) -> set[int]:
+        lines_to_remove: set[int] = set()
+
+        for i in range(len(lines)):
+            if self._is_empty_except_block(lines, i):
+                empty_pass_idx = self._find_empty_pass_line(lines, i)
+                if empty_pass_idx is not None:
+                    lines_to_remove.add(empty_pass_idx)
+
+        return lines_to_remove
+
+    def _is_empty_except_block(self, lines: list[str], line_idx: int) -> bool:
+        stripped = lines[line_idx].strip()
+        return stripped == "except: " or stripped.startswith("except ")
+
+    def _find_empty_pass_line(self, lines: list[str], except_idx: int) -> int | None:
+        for j in range(except_idx + 1, min(except_idx + 5, len(lines))):
+            next_line = lines[j].strip()
+            if not next_line:
+                continue
+            if next_line == "pass":
+                return j
+            break
+        return None
+
+    def _extract_function_content(
+        self, lines: list[str], func_info: dict[str, t.Any]
+    ) -> str:
+        start_line = func_info["line_start"] - 1
+        end_line = func_info.get("line_end", len(lines)) - 1
+
+        if start_line < 0 or end_line >= len(lines):
+            return ""
+
+        return "\n".join(lines[start_line : end_line + 1])
+
+    def _apply_function_extraction(
+        self,
+        content: str,
+        func_info: dict[str, t.Any],
+        extracted_helpers: list[dict[str, str]],
+    ) -> str:
+        lines = content.split("\n")
+
+        if not self._is_extraction_valid(lines, func_info, extracted_helpers):
+            return "\n".join(lines)
+
+        return self._perform_extraction(lines, func_info, extracted_helpers)
+
+    def _is_extraction_valid(
+        self,
+        lines: list[str],
+        func_info: dict[str, t.Any],
+        extracted_helpers: list[dict[str, str]],
+    ) -> bool:
+        start_line = func_info["line_start"] - 1
+        end_line = func_info.get("line_end", len(lines)) - 1
+
+        return bool(extracted_helpers) and start_line >= 0 and end_line < len(lines)
+
+    def _perform_extraction(
+        self,
+        lines: list[str],
+        func_info: dict[str, t.Any],
+        extracted_helpers: list[dict[str, str]],
+    ) -> str:
+        new_lines = self._replace_function_with_calls(
+            lines, func_info, extracted_helpers
+        )
+        return self._add_helper_definitions(new_lines, func_info, extracted_helpers)
+
+    def _replace_function_with_calls(
+        self,
+        lines: list[str],
+        func_info: dict[str, t.Any],
+        extracted_helpers: list[dict[str, str]],
+    ) -> list[str]:
+        start_line = func_info["line_start"] - 1
+        end_line = func_info.get("line_end", len(lines)) - 1
+        func_indent = len(lines[start_line]) - len(lines[start_line].lstrip())
+        indent = " " * (func_indent + 4)
+
+        new_func_lines = [lines[start_line]]
+        for helper in extracted_helpers:
+            new_func_lines.append(f"{indent}self.{helper['name']}()")
+
+        return lines[:start_line] + new_func_lines + lines[end_line + 1 :]
+
+    def _add_helper_definitions(
+        self,
+        new_lines: list[str],
+        func_info: dict[str, t.Any],
+        extracted_helpers: list[dict[str, str]],
+    ) -> str:
+        start_line = func_info["line_start"] - 1
+        class_end = self._find_class_end(new_lines, start_line)
+
+        for helper in extracted_helpers:
+            helper_lines = helper["content"].split("\n")
+            new_lines = (
+                new_lines[:class_end] + [""] + helper_lines + new_lines[class_end:]
+            )
+            class_end += len(helper_lines) + 1
+
+        return "\n".join(new_lines)
+
+    def _find_class_end(self, lines: list[str], func_start: int) -> int:
+        class_indent = self._find_class_indent(lines, func_start)
+        if class_indent is None:
+            return len(lines)
+        return self._find_class_end_line(lines, func_start, class_indent)
+
+    def _find_class_indent(self, lines: list[str], func_start: int) -> int | None:
+        for i in range(func_start, -1, -1):
+            if lines[i].strip().startswith("class "):
+                return len(lines[i]) - len(lines[i].lstrip())
+        return None
+
+    def _find_class_end_line(
+        self, lines: list[str], func_start: int, class_indent: int
+    ) -> int:
+        for i in range(func_start + 1, len(lines)):
+            line = lines[i]
+            if line.strip() and len(line) - len(line.lstrip()) <= class_indent:
+                return i
+        return len(lines)
+
 
 agent_registry.register(RefactoringAgent)
