@@ -1,10 +1,3 @@
-"""Workflow execution engine for MCP tools.
-
-This module handles the core workflow execution logic, including orchestrator setup,
-iteration management, and result handling. Split from execution_tools.py for better
-separation of concerns.
-"""
-
 import asyncio
 import time
 import typing as t
@@ -18,23 +11,67 @@ from .progress_tools import _update_progress
 async def execute_crackerjack_workflow(
     args: str, kwargs: dict[str, t.Any]
 ) -> dict[str, t.Any]:
-    """Execute the main crackerjack workflow with progress tracking."""
     job_id = str(uuid.uuid4())[:8]
 
+    # Initialize progress immediately
+    await _update_progress(
+        job_id,
+        {"status": "started", "args": args, "timestamp": time.time()},
+        0,
+        message="Crackerjack execution started",
+    )
+
+    # Start execution in background - no timeout!
+    context = get_context()
+    asyncio.create_task(_execute_crackerjack_background(job_id, args, kwargs, context))
+
+    # Return job_id immediately for progress monitoring
+    return {
+        "job_id": job_id,
+        "status": "running",
+        "message": "Execution started. Use get_job_progress(job_id) to monitor progress.",
+        "timestamp": time.time(),
+    }
+
+
+async def _execute_crackerjack_background(
+    job_id: str,
+    args: str,
+    kwargs: dict[str, t.Any],
+    context: t.Any,
+) -> None:
+    """Execute crackerjack workflow in background with progress updates."""
     try:
-        return await _execute_crackerjack_sync(job_id, args, kwargs, get_context())
+        result = await _execute_crackerjack_sync(job_id, args, kwargs, context)
+
+        # Update final progress with result
+        await _update_progress(
+            job_id,
+            {
+                "status": result.get("status", "completed"),
+                "result": result,
+                "timestamp": time.time(),
+                "final": True,
+            },
+            100,
+            message=f"Execution {result.get('status', 'completed')}",
+        )
     except Exception as e:
-        # Add full traceback for debugging
         import traceback
 
-        error_details = traceback.format_exc()
-        return {
-            "job_id": job_id,
-            "status": "failed",
-            "error": f"Execution failed: {e}",
-            "traceback": error_details,
-            "timestamp": time.time(),
-        }
+        # Update progress with error
+        await _update_progress(
+            job_id,
+            {
+                "status": "failed",
+                "error": str(e),
+                "traceback": traceback.format_exc(),
+                "timestamp": time.time(),
+                "final": True,
+            },
+            -1,
+            message=f"Execution failed: {e}",
+        )
 
 
 async def _execute_crackerjack_sync(
@@ -43,13 +80,10 @@ async def _execute_crackerjack_sync(
     kwargs: dict[str, t.Any],
     context: t.Any,
 ) -> dict[str, t.Any]:
-    """Execute crackerjack workflow synchronously with progress tracking."""
-    # Initialize execution environment
     setup_result = await _initialize_execution(job_id, args, kwargs, context)
     if setup_result.get("status") == "failed":
         return setup_result
 
-    # Set up orchestrator
     orchestrator_result = await _setup_orchestrator(
         job_id, args, kwargs, setup_result["working_dir"], context
     )
@@ -58,7 +92,6 @@ async def _execute_crackerjack_sync(
 
     orchestrator = orchestrator_result["orchestrator"]
 
-    # Run workflow iterations
     return await _run_workflow_iterations(job_id, orchestrator, kwargs, context)
 
 
@@ -68,7 +101,6 @@ async def _initialize_execution(
     kwargs: dict[str, t.Any],
     context: t.Any,
 ) -> dict[str, t.Any]:
-    """Initialize execution environment and validate parameters."""
     _update_progress(
         job_id,
         {
@@ -79,7 +111,8 @@ async def _initialize_execution(
         context,
     )
 
-    # Validate working directory
+    await _ensure_websocket_server_running(job_id, context)
+
     working_dir = kwargs.get("working_directory", ".")
     from pathlib import Path
 
@@ -115,7 +148,6 @@ async def _setup_orchestrator(
     working_dir: t.Any,
     context: t.Any,
 ) -> dict[str, t.Any]:
-    """Set up the appropriate orchestrator based on configuration."""
     _update_progress(
         job_id,
         {
@@ -126,9 +158,7 @@ async def _setup_orchestrator(
         context,
     )
 
-    use_advanced = kwargs.get(
-        "advanced_orchestration", False
-    )  # Temporarily disable advanced orchestration
+    use_advanced = kwargs.get("advanced_orchestration", False)
 
     try:
         if use_advanced:
@@ -155,19 +185,19 @@ async def _setup_orchestrator(
 async def _create_advanced_orchestrator(
     working_dir: t.Any, kwargs: dict[str, t.Any], context: t.Any
 ) -> t.Any:
-    """Create advanced async orchestrator with dependency injection."""
     from pathlib import Path
 
     from crackerjack.core.async_workflow_orchestrator import AsyncWorkflowOrchestrator
-    from crackerjack.core.enhanced_container import EnhancedContainer
+    from crackerjack.core.enhanced_container import EnhancedDependencyContainer
 
-    container = EnhancedContainer()
+    container = EnhancedDependencyContainer()
 
-    # Register services with the container
     await _register_core_services(container, Path(working_dir))
 
     orchestrator = AsyncWorkflowOrchestrator(
         pkg_path=Path(working_dir),
+        verbose=kwargs.get("verbose", False),
+        debug=kwargs.get("debug", False),
     )
 
     return orchestrator
@@ -176,7 +206,6 @@ async def _create_advanced_orchestrator(
 def _create_standard_orchestrator(
     working_dir: t.Any, kwargs: dict[str, t.Any]
 ) -> t.Any:
-    """Create standard synchronous orchestrator."""
     from pathlib import Path
 
     from crackerjack.core.workflow_orchestrator import WorkflowOrchestrator
@@ -185,46 +214,39 @@ def _create_standard_orchestrator(
 
 
 async def _register_core_services(container: t.Any, working_dir: t.Any) -> None:
-    """Register core services with the dependency injection container."""
     from rich.console import Console
 
-    from crackerjack.core.enhanced_container import ServiceLifetime
     from crackerjack.managers.hook_manager import AsyncHookManager
-    from crackerjack.managers.publish_manager import PublishManager
-    from crackerjack.managers.test_manager import TestManager
+    from crackerjack.managers.publish_manager import PublishManagerImpl
+    from crackerjack.managers.test_manager import TestManagementImpl
     from crackerjack.models.protocols import (
-        HookManagerProtocol,
-        PublishManagerProtocol,
+        FileSystemInterface,
+        HookManager,
+        PublishManager,
         TestManagerProtocol,
     )
     from crackerjack.services.enhanced_filesystem import EnhancedFileSystemService
 
     console = Console()
 
-    # Register managers
-    container.register_service(
-        HookManagerProtocol,
-        AsyncHookManager(console, working_dir),
-        ServiceLifetime.SINGLETON,
+    container.register_singleton(
+        HookManager,
+        factory=lambda: AsyncHookManager(console, working_dir),
     )
 
-    container.register_service(
+    container.register_singleton(
         TestManagerProtocol,
-        TestManager(console, working_dir),
-        ServiceLifetime.SINGLETON,
+        factory=lambda: TestManagementImpl(console, working_dir),
     )
 
-    container.register_service(
-        PublishManagerProtocol,
-        PublishManager(console, working_dir),
-        ServiceLifetime.SINGLETON,
+    container.register_singleton(
+        PublishManager,
+        factory=lambda: PublishManagerImpl(console, working_dir),
     )
 
-    # Register filesystem service
-    container.register_service(
-        EnhancedFileSystemService,
-        EnhancedFileSystemService(),
-        ServiceLifetime.SINGLETON,
+    container.register_singleton(
+        FileSystemInterface,
+        factory=EnhancedFileSystemService,
     )
 
 
@@ -234,21 +256,30 @@ async def _run_workflow_iterations(
     kwargs: dict[str, t.Any],
     context: t.Any,
 ) -> dict[str, t.Any]:
-    """Run workflow iterations until completion or max attempts."""
     options = _create_workflow_options(kwargs)
-    max_iterations = kwargs.get("max_iterations", 10)
+    max_iterations = kwargs.get("max_iterations", 5)
 
-    for iteration in range(max_iterations):
-        _update_progress(
-            job_id,
-            {
-                "type": "iteration",
-                "iteration": iteration + 1,
-                "max_iterations": max_iterations,
-                "status": "running",
-            },
-            context,
+    keep_alive_task = asyncio.create_task(_keep_alive_heartbeat(job_id, context))
+
+    try:
+        result = await _execute_iterations_loop(
+            job_id, orchestrator, options, kwargs, max_iterations, context
         )
+        return result
+    finally:
+        await _cleanup_keep_alive_task(keep_alive_task)
+
+
+async def _execute_iterations_loop(
+    job_id: str,
+    orchestrator: t.Any,
+    options: t.Any,
+    kwargs: dict[str, t.Any],
+    max_iterations: int,
+    context: t.Any,
+) -> dict[str, t.Any]:
+    for iteration in range(max_iterations):
+        _update_iteration_progress(job_id, iteration, max_iterations, context)
 
         try:
             success = await _execute_single_iteration(
@@ -256,17 +287,10 @@ async def _run_workflow_iterations(
             )
 
             if success:
-                # Attempt coverage improvement after successful execution (if enabled)
-                coverage_result = None
-                if kwargs.get("boost_coverage", False):  # Temporarily disabled
-                    coverage_result = await _attempt_coverage_improvement(
-                        job_id, orchestrator, context
-                    )
-                return _create_success_result(
-                    job_id, iteration + 1, context, coverage_result
+                return await _handle_iteration_success(
+                    job_id, iteration, orchestrator, kwargs, context
                 )
 
-            # Handle retry logic
             if iteration < max_iterations - 1:
                 await _handle_iteration_retry(job_id, iteration, context)
 
@@ -276,14 +300,76 @@ async def _run_workflow_iterations(
     return _create_failure_result(job_id, max_iterations, context)
 
 
+def _update_iteration_progress(
+    job_id: str, iteration: int, max_iterations: int, context: t.Any
+) -> None:
+    _update_progress(
+        job_id,
+        {
+            "type": "iteration",
+            "iteration": iteration + 1,
+            "max_iterations": max_iterations,
+            "status": "running",
+        },
+        context,
+    )
+
+
+async def _handle_iteration_success(
+    job_id: str,
+    iteration: int,
+    orchestrator: t.Any,
+    kwargs: dict[str, t.Any],
+    context: t.Any,
+) -> dict[str, t.Any]:
+    coverage_result = None
+    if kwargs.get("boost_coverage", False):
+        coverage_result = await _attempt_coverage_improvement(
+            job_id, orchestrator, context
+        )
+    return _create_success_result(job_id, iteration + 1, context, coverage_result)
+
+
+async def _cleanup_keep_alive_task(keep_alive_task: asyncio.Task[t.Any]) -> None:
+    if not keep_alive_task.cancelled():
+        keep_alive_task.cancel()
+        try:
+            await keep_alive_task
+        except asyncio.CancelledError:
+            pass
+
+
+async def _keep_alive_heartbeat(job_id: str, context: t.Any) -> None:
+    try:
+        while True:
+            await asyncio.sleep(60)
+            _update_progress(
+                job_id,
+                {
+                    "type": "keep_alive",
+                    "status": "heartbeat",
+                    "timestamp": time.time(),
+                    "message": "Keep-alive heartbeat to prevent connection timeout",
+                },
+                context,
+            )
+    except asyncio.CancelledError:
+        _update_progress(
+            job_id,
+            {
+                "type": "keep_alive",
+                "status": "cancelled",
+                "timestamp": time.time(),
+            },
+            context,
+        )
+
+
 def _create_workflow_options(kwargs: dict[str, t.Any]) -> t.Any:
-    """Create workflow options from kwargs."""
     from types import SimpleNamespace
 
-    # Create options object with all required attributes from OptionsProtocol
     options = SimpleNamespace()
 
-    # Core execution options
     options.commit = kwargs.get("commit", False)
     options.interactive = kwargs.get("interactive", False)
     options.no_config_updates = kwargs.get("no_config_updates", False)
@@ -295,11 +381,9 @@ def _create_workflow_options(kwargs: dict[str, t.Any]) -> t.Any:
     options.ai_agent = kwargs.get("ai_agent", True)
     options.async_mode = kwargs.get("async_mode", True)
 
-    # Test options
     options.test_workers = kwargs.get("test_workers", 0)
     options.test_timeout = kwargs.get("test_timeout", 0)
 
-    # Publishing options
     options.publish = kwargs.get("publish")
     options.bump = kwargs.get("bump")
     options.all = kwargs.get("all")
@@ -309,23 +393,18 @@ def _create_workflow_options(kwargs: dict[str, t.Any]) -> t.Any:
     options.cleanup_pypi = kwargs.get("cleanup_pypi", False)
     options.keep_releases = kwargs.get("keep_releases", 10)
 
-    # Server options
     options.start_mcp_server = kwargs.get("start_mcp_server", False)
 
-    # Hook options
     options.update_precommit = kwargs.get("update_precommit", False)
     options.experimental_hooks = kwargs.get("experimental_hooks", False)
     options.enable_pyrefly = kwargs.get("enable_pyrefly", False)
     options.enable_ty = kwargs.get("enable_ty", False)
 
-    # Cleanup options
     options.cleanup = kwargs.get("cleanup")
 
-    # Coverage and progress
     options.coverage = kwargs.get("coverage", False)
     options.track_progress = kwargs.get("track_progress", False)
 
-    # Speed options
     options.fast = kwargs.get("fast", False)
     options.comp = kwargs.get("comp", False)
 
@@ -339,40 +418,39 @@ async def _execute_single_iteration(
     iteration: int,
     context: t.Any,
 ) -> bool:
-    """Execute a single workflow iteration."""
     try:
-        # Check for orchestrator workflow methods
-        if hasattr(orchestrator, "run_complete_workflow"):
-            # Standard WorkflowOrchestrator method is async
-            result = orchestrator.run_complete_workflow(options)
-            if result is None:
-                raise ValueError(
-                    "Method run_complete_workflow returned None instead of awaitable"
-                )
-            return await result
-        elif hasattr(orchestrator, "run_complete_workflow_async"):
+        if hasattr(orchestrator, "run_complete_workflow_async"):
             result = orchestrator.run_complete_workflow_async(options)
             if result is None:
                 raise ValueError(
                     "Method run_complete_workflow_async returned None instead of awaitable"
                 )
-            return await result
+            workflow_result: bool = await result
+            return workflow_result
+        elif hasattr(orchestrator, "run_complete_workflow"):
+            result = orchestrator.run_complete_workflow(options)
+            if result is None:
+                raise ValueError(
+                    "Method run_complete_workflow returned None instead of awaitable"
+                )
+            workflow_result: bool = await result
+            return workflow_result
         elif hasattr(orchestrator, "execute_workflow"):
             result = orchestrator.execute_workflow(options)
             if result is None:
                 raise ValueError(
                     "Method execute_workflow returned None instead of awaitable"
                 )
-            return await result
+            workflow_result: bool = await result
+            return workflow_result
         elif hasattr(orchestrator, "run"):
-            # Fallback for synchronous orchestrators
-            return orchestrator.run(options)
+            run_result: bool = orchestrator.run(options)
+            return run_result
         else:
             raise ValueError(
                 f"Orchestrator {type(orchestrator)} has no recognized workflow execution method"
             )
     except Exception as e:
-        # Add detailed error info for debugging
         raise RuntimeError(
             f"Error in _execute_single_iteration (iteration {iteration}): {e}"
         ) from e
@@ -384,7 +462,6 @@ def _create_success_result(
     context: t.Any,
     coverage_result: dict[str, t.Any] | None = None,
 ) -> dict[str, t.Any]:
-    """Create success result with completion data."""
     result = {
         "job_id": job_id,
         "status": "completed",
@@ -401,7 +478,6 @@ def _create_success_result(
 
 
 async def _handle_iteration_retry(job_id: str, iteration: int, context: t.Any) -> None:
-    """Handle retry logic between iterations."""
     _update_progress(
         job_id,
         {
@@ -413,14 +489,12 @@ async def _handle_iteration_retry(job_id: str, iteration: int, context: t.Any) -
         context,
     )
 
-    # Brief pause between iterations
     await asyncio.sleep(1)
 
 
 async def _handle_iteration_error(
     job_id: str, iteration: int, error: Exception, context: t.Any
 ) -> dict[str, t.Any]:
-    """Handle errors during iteration execution."""
     _update_progress(
         job_id,
         {
@@ -444,7 +518,6 @@ async def _handle_iteration_error(
 async def _attempt_coverage_improvement(
     job_id: str, orchestrator: t.Any, context: t.Any
 ) -> dict[str, t.Any]:
-    """Attempt proactive coverage improvement after successful workflow execution."""
     try:
         _update_progress(
             job_id,
@@ -456,23 +529,19 @@ async def _attempt_coverage_improvement(
             context,
         )
 
-        # Get project path from orchestrator
         project_path = getattr(orchestrator, "pkg_path", None)
         if not project_path:
             return {"status": "skipped", "reason": "No project path available"}
 
-        # Import coverage improvement orchestrator
         from crackerjack.orchestration.coverage_improvement import (
             create_coverage_improvement_orchestrator,
         )
 
-        # Create coverage orchestrator
         coverage_orchestrator = await create_coverage_improvement_orchestrator(
             project_path,
             console=getattr(orchestrator, "console", None),
         )
 
-        # Check if improvement is needed
         should_improve = await coverage_orchestrator.should_improve_coverage()
         if not should_improve:
             _update_progress(
@@ -480,18 +549,16 @@ async def _attempt_coverage_improvement(
                 {
                     "type": "coverage_improvement",
                     "status": "skipped",
-                    "message": "Coverage improvement not needed (already at 100%)",
+                    "message": "Coverage improvement not needed (already at 100 %)",
                 },
                 context,
             )
-            return {"status": "skipped", "reason": "Coverage at 100%"}
+            return {"status": "skipped", "reason": "Coverage at 100 %"}
 
-        # Create agent context (simplified)
         from crackerjack.agents.base import AgentContext
 
         agent_context = AgentContext(project_path=project_path, console=None)
 
-        # Execute coverage improvement
         _update_progress(
             job_id,
             {
@@ -506,7 +573,6 @@ async def _attempt_coverage_improvement(
             agent_context
         )
 
-        # Update progress with results
         if improvement_result["status"] == "completed":
             _update_progress(
                 job_id,
@@ -555,7 +621,6 @@ async def _attempt_coverage_improvement(
 def _create_failure_result(
     job_id: str, max_iterations: int, context: t.Any
 ) -> dict[str, t.Any]:
-    """Create failure result when max iterations exceeded."""
     return {
         "job_id": job_id,
         "status": "failed",
@@ -563,3 +628,31 @@ def _create_failure_result(
         "timestamp": time.time(),
         "success": False,
     }
+
+
+async def _ensure_websocket_server_running(job_id: str, context: t.Any) -> None:
+    try:
+        from crackerjack.mcp.progress_components import ServiceManager
+
+        service_manager = ServiceManager()
+        await service_manager.ensure_services_running()
+
+        _update_progress(
+            job_id,
+            {
+                "type": "service_check",
+                "status": "websocket_ready",
+                "message": "WebSocket server ensured running for progress tracking",
+            },
+            context,
+        )
+    except Exception as e:
+        _update_progress(
+            job_id,
+            {
+                "type": "service_check",
+                "status": "websocket_warning",
+                "message": f"WebSocket server auto-start failed: {e}. Progress tracking may be limited.",
+            },
+            context,
+        )
